@@ -1,7 +1,7 @@
 import logging
 from typing import Union
 
-from tlstrust import TrustStore, context
+from tlstrust import TrustStore, context, stores
 from ...exceptions import EvaluationNotRelevant, NoLogEvaluation
 from ...transport import TLSTransport
 from ...certificate import BaseCertificate, RootCertificate
@@ -25,6 +25,16 @@ class EvaluationTask(BaseEvaluationTask):
             self.substitution_metadata["reason"] = reason
             raise NoLogEvaluation
 
-        return TrustStore(certificate.subject_key_identifier).check_trust(
+        store = TrustStore(certificate.subject_key_identifier)
+        self.substitution_metadata["root_store_name"] = context.ANDROID_OREO
+        self.substitution_metadata["store_version"] = stores.android_8.__version__
+        self.substitution_metadata["store_description"] = stores.android_8.__description__
+        self.substitution_metadata["short_name"] = context.SHORT_LOOKUP.get(context.ANDROID_OREO, context.ANDROID_OREO)
+        try:
+            self.substitution_metadata["exists_in_store"] = store.exists(context_type=context.PLATFORM_ANDROID8)
+            self.substitution_metadata["expired_in_store"] = store.expired_in_store(context_type=context.PLATFORM_ANDROID8)
+        except FileExistsError:
+            self.substitution_metadata["exists_in_store"] = False
+        return store.check_trust(
             context_type=context.PLATFORM_ANDROID8
         )
